User interface for contact.engineering
======================================

Purpose
-------

This plugin contains the user-facing interface of contact.engineering. It
consists of static HTML files and Vue.js applications.

Installation
------------

For production:

.. code-block:: bash

    pip install ce-ui

For development:

Clone project, enter project directory and run

.. code-block:: bash

    pip install -e .[dev]
